Fix CUDA clang again with new C++11 usages

This commit is contained in:
Antonio Sanchez
2025-03-13 20:47:31 -07:00
parent 6aa0143851
commit 0ac1fc52dd
6 changed files with 9 additions and 19 deletions

View File

@@ -1220,7 +1220,7 @@ struct TensorEvaluator<const TensorContractionOp<Indices, LeftArgType, RightArgT
typedef typename PacketType<CoeffReturnType, GpuDevice>::type PacketReturnType;
enum {
Layout = TensorEvaluator<LeftArgType, Device>::Layout,
Layout = TensorEvaluator<LeftArgType, Device>::Layout
};
// Most of the code is assuming that both input tensors are ColMajor. If the

View File

@@ -606,7 +606,7 @@ __global__ void EigenConvolutionKernel1D(
}
__syncthreads();
}
};
}
template <typename InputEvaluator, typename Index, typename InputDims,
int StaticKernelSizeX, int StaticKernelSizeY>
@@ -674,7 +674,7 @@ __global__ void EigenConvolutionKernel2D(
__syncthreads();
}
};
}
template <typename InputEvaluator, typename Index, typename InputDims>
__global__ void EigenConvolutionKernel3D(
@@ -740,9 +740,7 @@ __global__ void EigenConvolutionKernel3D(
}
__syncthreads();
}
};
}
template<typename Indices, typename InputArgType, typename KernelArgType>
struct TensorEvaluator<const TensorConvolutionOp<Indices, InputArgType, KernelArgType>, GpuDevice>

View File

@@ -78,7 +78,7 @@ struct PacketType<half, GpuDevice> {
HasLog = 1,
HasLog1p = 0,
HasLog10 = 0,
HasPow = 1,
HasPow = 1
};
};
#endif